#
# spec file for package libminizinc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libminizinc
Version:        2.7.6
Release:        1.1
Summary:        A high-level constraint modelling language
Group:          Productivity/Scientific/Math
License:        MPL-2.0
URL:            https://www.minizinc.org/
Source:         https://github.com/MiniZinc/libminizinc/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 3.4.0
BuildRequires:  gcc-c++
BuildRequires:  gecode-devel
BuildRequires:  pkgconfig(mpfr)

%description
MiniZinc is a free and open-source constraint modeling language.

%package -n minizinc
Summary:        A high-level constraint modelling language
Recommends:     gecode-minizinc

%description -n minizinc
You can use MiniZinc to model constraint satisfaction and optimisation
problems in a high-level, solver-independent way, taking advantage of
a large library of pre-defined constraints. Your model is then
compiled into FlatZinc, a solver input language that is understood
by a wide range of solvers.

%package devel
Summary:        A high-level constraint modelling language
Group:          Development/Libraries/C and C++
Requires:       minizinc = %{version}

%description devel
MiniZinc is a free and open-source constraint modeling language.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%post -n minizinc -p /sbin/ldconfig
%postun -n minizinc -p /sbin/ldconfig

%files -n minizinc
%license LICENSE.txt
%doc changes.rst README.md
%{_bindir}/*
%{_datadir}/minizinc
%{_libdir}/libmzn*

%files devel
%{_includedir}/minizinc
%{_libdir}/cmake/libminizinc

%changelog
* Thu Nov  9 2023 Dirk Müller <dmueller@suse.com>
- update to 2.7.6:
  * Change the library and solver configuration path of builtin
    version of Chuffed to prevent file conflicts
  * Use the verbose compilation flag to control the verbosity of
    the MIP domains stage
  * Introduces the ``arg_val`` and ``arg_val_weak`` globals that
    return the index of the first occurrence of a value in a given
    array.
  * Introduces the ``var_perm_sym`` and ``var_sqr_sym`` symmetry
    breaking globals.
  * Enable parallel search for the built-in Gecode presolver.
  * Use native Qt dark mode on Windows where supported.
  * Improve behaviour of the custom solver parameter dialog.
  * ``ASTString`` constructor that uses ``std::string`` is now
    explicit to avoid unexpected or unnecessary GC allocation.
  * Circular definitions through the use of annotations will now
    be reported as type errors, rather incurring infinite recursion
  * Optimize the compilation of identical calls in different
    contexts by recursively changing the contexts of the (uncompiled)
    dependent calls, instead of flattening multiple times.
  * Change domains of set variables when encountering (par)
    equalities, or negated ``in`` constraints at the root level.
  * Calls to ``min`` and ``max`` with ``par set of int`` type
    argument will now be undefined (becoming ``false`` in the
    closest Boolean context). This makes them consistent with
    the calls with an argument of type ``var set of int``.
  * Note that previous behaviour would have returned ``infinity``
    or ``-infinity`` respectively (:bugref:`661`).
  * Only show MOOC error code when response is actually an error
  * Add documentation for ``--input-is-flatzinc`` flag
  * Add ``ceil``, ``floor`` and ``round`` functions for ``var
    float``, and corresponding FlatZinc builtins ``float_ceil``,
    ``float_floor`` and ``float_round`` that can be overridden
    by solvers in the new ``redefinitions-2.7.1.mzn`` library file
  * Fix highlighting of multiline comments starting with ``/*/``
  * Fix bundling of incompatible OpenSSL version in linux
    packages.
  * Support for tuple and record types as well as type-inst
    synonyms has been added.
  * Extended enumerated types can now be constructed from non-
    contiguous sets.
  * WebAssembly is now fully supported as a target platform.
  * MiniZinc now includes a solver interface for the `HiGHS
    linear optimisation suite. HiGHS is included by default in
    the MiniZincIDE package, and available using ``--solver highs``.
  * The SCIP interface has been updated and is now compatible
    with version 7 and 8 only.
  * A solver's globals library specified in a configuration file
    will now always be passed to the compiler using the ``-G``
    flag. This allows users to easily override this library from
    command line when required.
  * Automatically detect Gurobi 10.0 and potential future
    versions.
  * Avoid loading all solver plugin DLLs on startup, instead
    loading when required.
  * The non-FlatZinc interfaces now also accept the ``--free-
    search`` flag in addition to the ``-f`` flag.
  * Ensure user config directory is created when modifying
    solver search paths (:idebugref:`167`).
  * Add tooltips to the CP-Profiler status bar legend.
  * Add support for mooc submissions which include file editing
    history.
  * bugfixes
* Sat Jul 16 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.6.4
  https://github.com/MiniZinc/libminizinc/blob/2.6.4/changes.rst
- Drop upstream patches:
  * 0001-Fix-missing-return-in-non-void-function.patch
  * 0001-Add-memory-include-required-for-unique_ptr.patch
* Sat May 21 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.6.3
  https://github.com/MiniZinc/libminizinc/blob/2.6.3/changes.rst
- Fix build with GCC 12.1.0, add
  0001-Add-memory-include-required-for-unique_ptr.patch
* Thu Apr 28 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Depend on gecode for building the presolver, and recommend the
  gecode-minizinc solver plugin.
* Tue Apr 26 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Initial package version (2.6.2)
